# RPi Remote control web interface
# by IZ8EWD www.pianetaradio.it
# v 1.0 beta

import RPi.GPIO as GPIO
import datetime

from flask import Flask, render_template

app = Flask(__name__)

GPIO.setmode(GPIO.BOARD)

#Create a dictionary called port_io to store the pin number, name and status
port_io = {
 11 : {'name' : 'Device 1', 'status' : GPIO.LOW},
 13 : {'name' : 'Device 2', 'status' : GPIO.LOW},
 15 : {'name' : 'Device 3', 'status' : GPIO.LOW},
 16 : {'name' : 'Device 4', 'status' : GPIO.LOW}
}

#Set each pin as an output and make it low
for pin in port_io:
   GPIO.setup(pin, GPIO.OUT)
   GPIO.output(pin, GPIO.LOW)


#Create the dynamic content of main page
@app.route("/")
def index():

#For each pin, read the pin state and store it in the port_io dictionary
 for pin in port_io:
  port_io[pin]['state'] = GPIO.input(pin)

#Read current time
 time = datetime.datetime.now()
 time_string = time.strftime("%Y-%m-%d %H:%M")
	
#Dictionary with return data for the html page
 return_data = {
  'port_io' : port_io,
  'return_message' : "Welcome",
  'return_time' : time_string
 }

#Create html page from template
 return render_template('remote_template.html', **return_data)


#Switch the pin status on user request and update the web interface
@app.route("/<pin_control>/", methods=['POST'])
def GPIO_control(pin_control):
 
 pin_control = int(pin_control)
 
 if port_io[pin_control]['status'] == GPIO.LOW:
  GPIO.output(pin_control, GPIO.HIGH) #Set the pin high

 else:
  port_io[pin_control]['status'] = GPIO.LOW
  GPIO.output(pin_control, GPIO.LOW) #Set the pin low

 port_io[pin_control]['status'] = GPIO.input(pin_control) #Read the pin value and assign to pin status in port_io
  
#Upadate the time
 time = datetime.datetime.now()
 time_string = time.strftime("%Y-%m-%d %H:%M")

#Update the return data in the html page
 return_data = {
  'port_io' : port_io,
  'return_message' : port_io[pin_control]['name'] + " is " + str(port_io[pin_control]['status']),
  'return_time' : time_string
 }
    
 return render_template('remote_template.html', **return_data)
	

if __name__ == "__main__":
 app.run(host="0.0.0.0", port=80, debug=False) #Web server running on localhost, port 80